{% extends '!layout.html' %}

{# Add github banner (from: https://github.com/blog/273-github-ribbons). #}
{% block header %}
  {{ super() }}
  {% if pagename == "index" %}
      <a href="https://github.com/calysto/metakernel"
         class="visible-desktop"><img
        style="position: absolute; top: 50px; right: 0; border: 0; z-index:1"
        src="https://s3.amazonaws.com/github/ribbons/forkme_right_white_ffffff.png"
        alt="Fork me on GitHub"></a>
  {% endif %}
{% endblock %}
